@@ -1,4 +1,6 @@
 import torch
+from PIL import Image
+from matplotlib import pyplot as plt
 
 from diamond.image_caption.utils import load_images_from_numpy
 from diamond.user_classes import ImagesData, ImageDescriptionSpec
@@ -45,18 +47,32 @@ class ImageObjectDetection:
 
     def plot_detected_objets(self):
         if self.plot:
-            # sample self.plot_sample images from self.images_to_show
-            for i in range(len(self.images_data.images_to_show)):
-                image = self.images_data.images_to_show[i]
-                bounding_boxes = self.diamond_collector["object detection"][i]
-                lables = [pred["label"] for pred in bounding_boxes]
-                # Draw bounding boxes and labels on original image
-                draw = ImageDraw.Draw(image)
-                for prediction in bounding_boxes:
-                    box = prediction["box"]
-                    label = prediction["label"]
-                    draw.rectangle([box["xmin"], box["ymin"], box["xmax"], box["ymax"]], outline="black", width=10)
-                    draw.text((box["xmin"], box["ymin"] - 20), label, fill="black")
+            try:
+                for i in range(len(self.images_data.images_to_show)):
+                    try:
+                        image = Image.fromarray(self.images_data.images_to_show[i])
+                    except:
+                        image = self.images_data.images_to_show[i]
+                    bounding_boxes = self.diamond_collector["object detection"][i]
+                    lables = []
+                    # Draw bounding boxes and labels on original image
+                    draw = ImageDraw.Draw(image)
+                    for prediction in bounding_boxes:
+                        box = prediction["box"]
+                        label = prediction["label"]
+                        lables.append(label)
+                        draw.rectangle([box["xmin"], box["ymin"], box["xmax"], box["ymax"]], outline="black", width=12)
+                        draw.text((box["xmin"], box["ymin"] - 20), label, fill="black")
+                    # Display image with bounding boxes
+                    fig, ax = plt.subplots(figsize=(15, 11))
+                    plt.title(lables)
+                    plt.imshow(image)
+                    plt.show()
+                    plt.close()
+                    if i > self.plot_sample:
+                        return None
+            except Exception as e:
+                print(f"Error while running model: {e}")
 
     def run(self):
         self.diamond_collector["object detection"] = self.detect_objects()
